@@ -52,10 +52,11 @@ def genbank_to_json(file):
                 locus +=1
             else:
                 out.write(line)
+    out.close()
     from Bio import GenBank
     with open(file+'.clean.gbk') as h:
         for r in GenBank.parse(h):
-            print(locus)
+            # print(r)
             lst = []
             for m in r.features:
                 lst.append(m)
